==> gtktalog-0.12.1.tar.gz: gtktalog-0.12.1/src/gtktalog/progressbar.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __PROGRESS_H__
#define __PROGRESS_H__

#include <config.h>
#ifdef OS_LINUX
#  include <sys/vfs.h>		
#endif
#if defined(OS_FREEBSD) || defined(OS_NETBSD)
#    include <sys/param.h>
#    include <sys/mount.h>
#    include <isofs/cd9660/cd9660_mount.h>
#endif
#include "config_common.h"
#include <gnome.h>


/* Return the size of the filesystem
   FIXME: Will take the size of the current filesystem.
        That means it won't work if you only try to catalog a part of a drive
*/
glong getStats (char *foldername);

/* Reset the internal variables of the progressBar */
void progress_reset ();

/* Indicate if a progress bar has just finished */
gboolean progress_needReset ();

/* Update the progress_bar */
gint progress_timeout (gpointer pstru);

/* Launch a timer to update the progressBar 
   Will stop by itself at 100% */
void progress_createTimeout ();

/* Set the total */
void progress_setTotal (gulong total, gint reg);

/* Set the current value */
void progress_setCurrent (gulong current, gint reg);
/* Get The current value */
gulong progress_getCurrent (gint reg);

/* Set a message in the appbar */
void progress_setStatus(gchar *msg, gint reg);

/* Set the gnome appbar to use */
void progress_setGnomeAppBar(GtkWidget* appbar, gint reg);

/* Initializes the appbars handler */
void progress_initGnomeAppBar ();

/* Frees the appbars handler memory*/
void progress_killGnomeAppBar ();

#endif

==> gtktalog-0.13.1.tar.gz: gtktalog-0.13.1/src/gtktalog/progressbar.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __PROGRESS_H__
#define __PROGRESS_H__

#include <config.h>
#ifdef OS_LINUX
#  include <sys/vfs.h>		
#endif
#if defined(OS_FREEBSD) || defined(OS_NETBSD)
#    include <sys/param.h>
#    include <sys/mount.h>
#    include <isofs/cd9660/cd9660_mount.h>
#endif
#include "config_common.h"
#include <gnome.h>


/* Return the size of the filesystem
   FIXME: Will take the size of the current filesystem.
        That means it won't work if you only try to catalog a part of a drive
*/
glong getStats (char *foldername);

/* Reset the internal variables of the progressBar */
void progress_reset ();

/* Indicate if a progress bar has just finished */
gboolean progress_needReset ();

/* Update the progress_bar */
gint progress_timeout (gpointer pstru);

/* Launch a timer to update the progressBar 
   Will stop by itself at 100% */
void progress_createTimeout (gpointer pstru);

/* Set the total */
void progress_setTotal (gulong total, gint reg);

/* Set the current value */
void progress_setCurrent (gulong current, gint reg);
/* Get The current value */
gulong progress_getCurrent (gint reg);

/* Set a message in the appbar */
void progress_setStatus(gchar *msg, gint reg);

/* Set the gnome appbar to use */
void progress_setGnomeAppBar(GtkWidget* appbar, gint reg);

/* Initializes the appbars handler */
void progress_initGnomeAppBar ();

/* Frees the appbars handler memory*/
void progress_killGnomeAppBar ();

#endif
